@@ -10,15 +10,35 @@ from civetqc.model import Model
 
 
 def parse_args() -> argparse.Namespace:
-    parser = argparse.ArgumentParser(prog='civetqc')
-    parser.add_argument("-v", "--version", action="version", version=f"%(prog)s {version('civetqc')}")
-    parser.add_argument("input_path", type=Path, help='path to file or directory with CIVET QC outputs')
-    parser.add_argument('--threshold', type=float, default=Model.get_default_threshold(), metavar='',
-        help='probability above which a failure will be predicted (default: %(default)s)')
-    parser.add_argument("--output_dir",  type=Path, default=Path.cwd(), metavar='',
-        help='directory for results (default: %(default)s)')
-    parser.add_argument("--output_format", type=str, default='csv', choices=['csv', 'json'], metavar='',
-        help='format for output file: csv, json (default: %(default)s)')
+    parser = argparse.ArgumentParser(prog="civetqc")
+    parser.add_argument(
+        "-v", "--version", action="version", version=f"%(prog)s {version('civetqc')}"
+    )
+    parser.add_argument(
+        "input_path", type=Path, help="path to file or directory with CIVET QC outputs"
+    )
+    parser.add_argument(
+        "--threshold",
+        type=float,
+        default=Model.get_default_threshold(),
+        metavar="",
+        help="probability above which a failure will be predicted (default: %(default)s)",
+    )
+    parser.add_argument(
+        "--output_dir",
+        type=Path,
+        default=Path.cwd(),
+        metavar="",
+        help="directory for results (default: %(default)s)",
+    )
+    parser.add_argument(
+        "--output_format",
+        type=str,
+        default="csv",
+        choices=["csv", "json"],
+        metavar="",
+        help="format for output file: csv, json (default: %(default)s)",
+    )
     return parser.parse_args()
 
 
@@ -28,7 +48,10 @@ def verify_args(args: argparse.Namespace) -> None:
     elif not args.output_dir.is_dir():
         raise NotADirectoryError(f"Output directory does not exist: {args.output_dir}")
     if not 1 > args.threshold > 0:
-        raise ValueError(f"Threshold must be greater than zero and less than one, got {args.threshold}")
+        raise ValueError(
+            f"Threshold must be greater than zero and less than one, got {args.threshold}"
+        )
+
 
 def load_civet_data(input_path: Path) -> CivetData:
     if input_path.is_file():
@@ -50,11 +73,12 @@ def main() -> None:
     qc_data = QCRatingsData(civet_data.subject_ids, predicted_ratings, probabilities)
 
     output_filepath = args.output_dir.joinpath(f"civetqc.{args.output_format}")
-    if args.output_format == 'csv':
+    if args.output_format == "csv":
         qc_data.to_csv(output_filepath)
-    
-    elif args.output_format == 'json':
+
+    elif args.output_format == "json":
         qc_data.to_json(output_filepath)
-    
-if __name__ == '__main__':
+
+
+if __name__ == "__main__":
     main()
